# yam-common

Shared utilities for the YAM arm LeRobot plugins.

Includes the motor chain controller, MuJoCo gravity compensation, and gripper
utilities used by both the follower robot and leader teleoperator packages.


